"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateName = require("sillyname");
require("isomorphic-fetch");
const clone_1 = require("./clone");
const api_1 = require("../api/api");
const utils_1 = require("../utils/utils");
const file_1 = require("../utils/file");
const validation_1 = require("../utils/validation");
const constants_1 = require("../utils/constants");
const debug = require('debug')('graphcool');
exports.default = (props, env) => __awaiter(this, void 0, void 0, function* () {
    const { resolver, out } = env;
    if (props.copyProjectId) {
        if (props.region) {
            throw new Error(constants_1.cantCopyAcrossRegions);
        }
        // clone
        const includes = props.copyOptions || 'all';
        const includeMutationCallbacks = includes === 'all' || includes === 'mutation-callbacks';
        const includeData = includes === 'all' || includes === 'data';
        const cloneProps = {
            sourceProjectId: props.copyProjectId,
            projectFile: props.projectFile,
            outputPath: props.outputPath,
            name: props.name,
            includeData,
            includeMutationCallbacks
        };
        yield clone_1.default(cloneProps, env);
    }
    else {
        // create new
        const projectFiles = resolver.projectFiles('.');
        if (projectFiles.length > 0 && !props.outputPath) {
            throw new Error(constants_1.projectAlreadyExistsMessage(projectFiles));
        }
        if (props.name && !validation_1.isValidProjectName(props.name)) {
            throw new Error(constants_1.invalidProjectNameMessage(props.name));
        }
        const name = props.name || generateName();
        out.startSpinner(constants_1.creatingProjectMessage(name));
        try {
            // resolve schema
            const schemaUrl = props.schemaUrl;
            if (!file_1.isValidSchemaFilePath(schemaUrl)) {
                throw new Error(constants_1.invalidSchemaFileMessage(schemaUrl));
            }
            const schema = yield getSchema(schemaUrl, resolver);
            // create project
            const projectInfo = yield createProjectAndGetProjectInfo(name, schema, resolver, props.alias, props.region);
            if (!isBlankProject(props)) {
                file_1.writeProjectFile(projectInfo, resolver, props.outputPath);
            }
            else {
                file_1.writeBlankProjectFileWithInfo(projectInfo, resolver, props.outputPath);
            }
            out.stopSpinner();
            const message = constants_1.createdProjectMessage(name, projectInfo.projectId, utils_1.projectInfoToContents(projectInfo), props.outputPath);
            out.write(message);
        }
        catch (e) {
            out.stopSpinner();
            out.writeError(`${constants_1.couldNotCreateProjectMessage}`);
            if (e.errors) {
                const errors = api_1.parseErrors(e);
                const output = api_1.generateErrorOutput(errors);
                out.writeError(`${output}`);
            }
            else {
                throw e;
            }
        }
    }
});
function isBlankProject(props) {
    return props.schemaUrl === constants_1.sampleSchemaURL;
}
function createProjectAndGetProjectInfo(name, schema, resolver, alias, region) {
    return __awaiter(this, void 0, void 0, function* () {
        const projectInfo = yield api_1.createProject(name, schema.schema, resolver, alias, region);
        if (schema.source === constants_1.sampleSchemaURL) {
            projectInfo.schema = `${projectInfo.schema}\n\n# type Tweet {\n#   text: String!\n# }`;
        }
        return projectInfo;
    });
}
function getSchema(schemaUrl, resolver) {
    return __awaiter(this, void 0, void 0, function* () {
        if (schemaUrl.startsWith('http')) {
            const response = yield fetch(schemaUrl);
            const schema = yield response.text();
            return {
                schema,
                source: schemaUrl,
            };
        }
        else {
            return {
                schema: resolver.read(schemaUrl),
                source: schemaUrl,
            };
        }
    });
}
//# sourceMappingURL=init.js.map