"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../utils/constants");
const utils_1 = require("../utils/utils");
const chalk = require("chalk");
const figures = require("figures");
const Raven = require("raven");
const ora = require("ora");
const debug = require('debug')('graphcool');
class StdOut {
    write(message) {
        process.stdout.write(message);
    }
    writeError(message) {
        process.stderr.write(message);
    }
    startSpinner(message) {
        this.spinner = ora(message).start();
    }
    stopSpinner() {
        if (this.spinner) {
            this.spinner.stop();
        }
    }
    onError(error) {
        return __awaiter(this, void 0, void 0, function* () {
            // prevent the same error output twice
            const errorMessage = utils_1.makePartsEnclodesByCharacterBold(`Error: ${error.message}`, `\``);
            if (error.stack && !error.stack.startsWith(errorMessage)) {
                console.error(`${chalk.red(figures.cross)}  ${errorMessage}`);
                debug(error.stack);
            }
            else if (error.stack) {
                const errorLines = error.stack.split('\n');
                const firstErrorLine = errorLines[0];
                console.error(`${chalk.red(figures.cross)}  ${firstErrorLine}`);
                debug(error.stack);
            }
            else {
                console.error(JSON.stringify(error));
            }
            console.error(`\n${constants_1.setDebugMessage}\n${constants_1.contactUsInSlackMessage}\n`);
            yield new Promise(resolve => Raven.captureException(error, resolve));
            process.exit(1);
        });
    }
}
exports.default = StdOut;
//# sourceMappingURL=StdOut.js.map