"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os = require("os");
const path = require("path");
const chalk = require("chalk");
const figures = require("figures");
/*
 * Networking & URLs
 */
exports.authUIEndpoint = process.env.ENV === 'DEV' ? 'https://dev.console.graph.cool/cli/auth' : 'https://console.graph.cool/cli/auth';
exports.systemAPIEndpoint = process.env.ENV === 'DEV' ? 'https://dev.api.graph.cool/system' : 'https://api.graph.cool/system';
exports.authEndpoint = process.env.ENV === 'DEV' ? 'https://cli-auth-api.graph.cool/dev' : 'https://cli-auth-api.graph.cool/prod';
exports.docsEndpoint = process.env.ENV === 'DEV' ? 'https://dev.graph.cool/docs' : 'https://www.graph.cool/docs';
exports.consoleURL = (token, projectName) => `https://console.graph.cool/token?token=${token}${projectName ? `&redirect=/${encodeURIComponent(projectName)}` : ''}`;
exports.playgroundURL = (token, projectName) => `https://console.graph.cool/token?token=${token}&redirect=/${encodeURIComponent(projectName)}/playground`;
exports.sampleSchemaURL = `http://graphqlbin.com/empty.graphql`;
/*
 * Sentry
 */
exports.sentryDSN = 'https://6ef6eea3afb041f2aca71d08742a36d1:51bdc5643a7648ffbfb3d3017879467c@sentry.io/178603';
/*
 * File paths / names
 */
exports.graphcoolProjectFileName = 'project.graphcool';
exports.graphcoolCloneProjectFileName = (projectFileName) => projectFileName ?
    `clone-${projectFileName.startsWith(`./`) ? projectFileName.substring(2) : projectFileName}` : `clone-${exports.graphcoolProjectFileName}`;
exports.graphcoolConfigFilePath = path.join(os.homedir(), '.graphcoolrc');
exports.projectFileSuffix = '.graphcool';
exports.schemaFileSuffix = '.graphql';
exports.exampleSchema = `\
# \`User\` is a system type with special characteristics.
# You can read about it in the documentation:
# https://www.graph.cool/docs/reference/schema/system-artifacts-uhieg2shio/#user-type
type User {
  id: ID! @isUnique
  createdAt: DateTime!
  updatedAt: DateTime!
}

# \`File\` is a system type with special characteristics.
# You can read about it in the documentation:
# https://www.graph.cool/docs/reference/schema/system-artifacts-uhieg2shio/#file-type
type File {
  id: ID! @isUnique
  createdAt: DateTime!
  updatedAt: DateTime!
  contentType: String!
  name: String!
  secret: String! @isUnique
  size: Int!
  url: String! @isUnique
}

# You can easily add custom types, here is an example.
# If you want to add the \`Tweet\` type to your schema,
# remove the below comments and run \`graphcool push\`.
# type Tweet {
#   text: String!
# }`;
exports.blankProjectFileFromExampleSchema = (projectId, version) => `\
# project: ${projectId}
# version: ${version}


###########################################################################
# \`User\` and \`File\` are generated and have special characteristics.
# You can read about them in the documentation:
# https://www.graph.cool/docs/reference/schema/system-artifacts-uhieg2shio/
###########################################################################

type User {
  id: ID! @isUnique
  createdAt: DateTime!
  updatedAt: DateTime!
}

type File {
  id: ID! @isUnique
  createdAt: DateTime!
  updatedAt: DateTime!
  contentType: String!
  name: String!
  secret: String! @isUnique
  size: Int!
  url: String! @isUnique
}


###########################################################################
# You can easily add custom definitions, \`Tweet\` below is an example.
# If you want to add \`Tweet\` to your schema,
# remove the below comments and run \`graphcool push\`.
###########################################################################

# type Tweet {
#   text: String!
# }`;
/*
 * Terminal output: auth
 */
exports.openBrowserMessage = `You need to authenticate. Your browser will open shortly...`;
exports.couldNotRetrieveTokenMessage = `Whoops, something went wrong during authentication.
`;
exports.authenticationSuccessMessage = (email) => ` ${chalk.green(figures.tick)} Authenticated user: ${chalk.bold(email)}
`;
/*
 * Terminal output: create
 */
exports.creatingProjectMessage = (name) => `Creating project ${chalk.bold(name)}...`;
exports.createdProjectMessage = (name, projectId, projectFileContent, projectOutputPath) => `\
 ${chalk.green(figures.tick)} Created project ${chalk.bold(name)} (ID: ${projectId}) successfully.


   ${chalk.bold('Here is what you can do next:')}

   1) Open ${chalk.bold(projectOutputPath || 'project.graphcool')} in your editor to update your schema.
      You can push your changes using ${chalk.cyan('`graphcool push`')}.

   2) Use one of the following endpoints to connect to your GraphQL API:

        Simple API:   https://api.graph.cool/simple/v1/${projectId}
        Relay API:    https://api.graph.cool/relay/v1/${projectId}

   3) Edit your project using the Console. Run ${chalk.cyan('`graphcool console`')} to open it.
`;
exports.couldNotCreateProjectMessage = `\
Whoops, something went wrong while creating the project.

`;
// export const projectAlreadyExistsMessage = `\
// ${graphcoolProjectFileName} already exists for the current project. \
// Looks like you've already setup your backend.
// `
exports.projectAlreadyExistsMessage = (projectFiles) => `\
Found ${projectFiles.length} project ${projectFiles.length === 1 ? 'file' : 'files'} in the current directory. Looks like you've already setup your backend.
You can still use graphcool init --output file.graphcool to specify a custom output file.
`;
exports.cantCopyAcrossRegions = `\
A project can't be copied across regions. Please specify the --copy parameter without --region.
`;
exports.invalidProjectNameMessage = (projectName) => `\
'${projectName}' is not a valid project name. It must begin with an uppercase letter.
`;
exports.howDoYouWantToGetStarted = () => `\

  You are about to create a new Graphcool project.


  ${chalk.bold('How do you want to continue?')}

`;
exports.invalidSchemaFileMessage = (schemaFileName) => `\
Your schema file ${chalk.bold(schemaFileName)} is invalid. A schema file must end with ${chalk.bold(exports.schemaFileSuffix)}.
`;
/*
 * Terminal output: push
 */
exports.remoteSchemaAheadMessage = (remoteVersion, localVersion) => `\
The local version of your schema (${localVersion}) is behind the remote version (${remoteVersion}). Save your local changes and run ${chalk.cyan(`\`graphcool pull\``)} before retrying.`;
exports.noProjectFileForPushMessage = `\
Please provide a valid project file (${exports.graphcoolProjectFileName}) for the schema migration.
`;
exports.invalidProjectFileMessage = `\
The project file (${exports.graphcoolProjectFileName}) that you provided doesn't seem to be valid. Please make sure it contains the ID of your project.
`;
exports.pushingNewSchemaMessage = `\
Migrating the schema in your project...`;
exports.noActionRequiredMessage = `\
 ${chalk.green(figures.tick)} Identical schema, no action required.
`;
exports.migrationPerformedMessage = `\
 ${chalk.green(figures.tick)} Your schema was successfully updated. Here are the changes:
`;
exports.migrationErrorMessage = `\
There are issues with the new schema:

`;
exports.potentialDataLossMessage = `\
Your changes might result in data loss.
Review your changes with ${chalk.cyan(`\`graphcool status\``)} or use ${chalk.cyan(`\`graphcool push --force\``)} if you know what you're doing!
`;
exports.invalidProjectFilePathMessage = (projectFilePath) => `\
${projectFilePath} is not a valid project file (must end with ${exports.projectFileSuffix}).
`;
exports.multipleProjectFilesMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you want to push, e.g.: ${chalk.cyan(`\`graphcool push ${projectFiles[0]}\``)}`;
/*
 * Terminal output: projects
 */
exports.couldNotFetchProjectsMessage = `\
An error occured while trying to fetch your projects.
`;
/*
 * Terminal output: endpoints
 */
exports.endpointsMessage = (projectId) => `\
 The endpoints for your project are:

   Simple API:         https://api.graph.cool/simple/v1/${projectId}
   Relay API:          https://api.graph.cool/relay/v1/${projectId}
   Subscriptions API:  wss://subscriptions.graph.cool/v1/${projectId}
   File API:           https://api.graph.cool/file/v1/${projectId}
`;
exports.multipleProjectFilesForEndpointsMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you for which you want to display the endpoints, e.g.: ${chalk.cyan(`\`graphcool endpoints ${projectFiles[0]}\``)}`;
/*
 * Terminal output: pull
 */
exports.fetchingProjectDataMessage = `\
Fetching project data ...`;
exports.noProjectIdMessage = `\
Please provide a valid project ID.
`;
exports.wroteProjectFileMessage = (projectFile) => `\
 ${chalk.green(figures.tick)} Your project file (${chalk.bold(projectFile)}) was successfully updated. Reload it in your editor if needed.
`;
exports.pulledInitialProjectFileMessage = (projectFile) => `\
 ${chalk.green(figures.tick)} Your project file was written to ${chalk.bold(projectFile)}
`;
exports.newVersionMessage = (newVersion) => `\
The new schema version is ${chalk.bold(newVersion)}.
`;
exports.differentProjectIdWarningMessage = (inputProjectId, readProjectId) => `\
The project ID you provided (${inputProjectId}) is different than the one in the current project file (${readProjectId}).
This will override the current project file with a different project, do you still want to continue? [y|N]
`;
exports.warnOverrideProjectFileMessage = (projectFile) => `\
You are about to override the local project file ${chalk.bold(projectFile)}. Make sure to save local changes that you want to preserve.
Do you want to continue? [y|N]
`;
exports.multipleProjectFilesForPullMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you want for which you want to pull the new schema, e.g.: ${chalk.cyan(`\`graphcool pull ${projectFiles[0]}\``)}
`;
/*
 * Terminal output: export
 */
exports.exportingDataMessage = `\
Exporting your project data ...`;
exports.downloadUrlMessage = (url) => `\
 ${chalk.green(figures.tick)} You can download your project data by pasting this URL in a browser:

   ${chalk.blue(figures.pointer)} Download URL: ${url}
`;
exports.multipleProjectFilesForExportMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you for which you want to export the data, e.g.: ${chalk.cyan(`\`graphcool export ${projectFiles[0]}\``)}`;
/*
 * Terminal output: console
 */
exports.openedConsoleMessage = (projectName) => projectName ? `\
The Console for project ${chalk.bold(projectName)} was opened in your browser.
` : `\
The Console was opened in your browser.
`;
/*
 * Terminal output: clone
 */
exports.multipleProjectFilesForCloneMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one for which you want to clone the project, e.g.: ${chalk.cyan(`\`graphcool clone ${projectFiles[0]}\``)}
`;
exports.cloningProjectMessage = `\
Cloning your project ...`;
exports.clonedProjectMessage = (clonedProjectName, outputPath, projectId) => `\
 ${chalk.green(figures.tick)} Cloned your project as ${chalk.bold(clonedProjectName)}. The project file was written to ${chalk.bold(outputPath)}.

   Here are your endpoints:

        Simple API:   https://api.graph.cool/simple/v1/${projectId}
        Relay API:    https://api.graph.cool/relay/v1/${projectId}
`;
/*
 * Terminal output: playground
 */
exports.tooManyProjectFilesForPlaygroundMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you for which you want open the Playground, e.g.: ${chalk.cyan(`\`graphcool playground ${projectFiles[0]}\``)}
`;
exports.openedPlaygroundMessage = (projectName) => `\
The Playground for project ${chalk.bold(projectName)} was opened in your browser.
`;
/*
 * Terminal output: quickstart
 */
exports.openedQuickstartMessage = `\
The Quickstart tutorial was opened in your browser.
`;
/*
 * Terminal output: status
 */
exports.multipleProjectFilesForStatusMessage = (projectFiles) => `\
Found ${projectFiles.length} project files. You can specify the one you for which you want display the status, e.g.: ${chalk.cyan(`\`graphcool status ${projectFiles[0]}\``)}
`;
exports.localSchemaBehindRemoteMessage = (remoteVersion, localVersion) => `\
The local version of your schema (${localVersion}) is behind the remote version (${remoteVersion}).
Save your local changes and execute ${chalk.cyan(`\`graphcool pull\``)} before a schema migration.
`;
exports.remoteSchemaBehindLocalMessage = (remoteVersion, localVersion) => `\
The remote version (${remoteVersion}) is behind the local version (${localVersion}). Please don't make manual changes to the project file's header.
`;
exports.statusHeaderMessage = (projectId, version) => `\
Project ID: ${projectId}
Remote Schema Version: ${version}

`;
exports.everythingUpToDateMessage = `\
Everything up-to-date.
`;
exports.potentialChangesMessage = `\
Here are all the local changes:
`;
exports.usePushToUpdateMessage = `
Use ${chalk.cyan(`\`graphcool push\``)} to apply your schema changes.
`;
exports.issuesInSchemaMessage = `\
The current version of your schema contains some issues:

`;
exports.destructiveChangesInStatusMessage = `\

Pushing the current version of your schema can result in data loss.
Use ${chalk.cyan(`\`graphcool push --force\``)} if you know what you're doing!
`;
/*
 * Terminal output: delete
 */
exports.deletingProjectMessage = (projectId) => projectId ? `\
Deleting project with Id ${projectId} ...` : `\
Deleting projects ...`;
exports.deletingProjectsMessage = (projectIds) => `\
Deleting ${projectIds.length} projects ...`;
exports.deletedProjectMessage = (projectIds) => projectIds.length > 1 ? `\
${chalk.green(figures.tick)} Successfully deleted ${projectIds.length} projects.` : `\
${chalk.green(figures.tick)} Your project was successfully deleted.`;
exports.deletingProjectWarningMessage = `\
Are you absolutely sure you want to delete these projects? ${chalk.bold(`This operation can not be undone!`)} [y|N]`;
/*
 * Terminal output: general
 */
exports.contactUsInSlackMessage = `\
 * Get in touch if you need help: http://slack.graph.cool/`;
exports.setDebugMessage = `\
 * You can enable additional output by setting \`export DEBUG=graphcool\` and rerunning the command.
 * Open an issue on GitHub: https://github.com/graphcool/graphcool-cli.`;
exports.noProjectFileOrIdMessage = `\
No project file or project ID provided.
`;
exports.noProjectFileMessage = `\
No project file found.
`;
exports.notAuthenticatedMessage = `\
You're currently not logged in. You can use the auth command to authenticate with ${chalk.cyan(`\`graphcool auth\``)}
`;
exports.projectFileWasUpdatedMessage = (projectFile) => `\
Your project file ${chalk.bold(projectFile)} was updated. Reload it in your editor if needed.
`;
exports.canNotReadVersionFromProjectFile = (projectFile) => `\
No schema version specified in ${chalk.bold(projectFile)}.
`;
exports.canNotReadProjectIdFromProjectFile = `\
Could not read the project's ID from project file.
`;
exports.unknownOptionsWarning = (command, unknownOptions) => unknownOptions.length > 1 ? `\
${chalk.bold('Error:')} The following options are not recognized: ${chalk.red(`${unknownOptions.map(a => a)}`)}
Use ${chalk.cyan(`\`graphcool ${command} --help\``)} to see a list of all possible options.
` : `\
${chalk.bold('Error:')} The following option is not recognized: ${chalk.red(`${unknownOptions[0]}`)}
Use ${chalk.cyan(`\`graphcool ${command} --help\``)} to see a list of all possible options.
`;
//# sourceMappingURL=constants.js.map