"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const constants_1 = require("./constants");
const debug = require('debug')('graphcool');
/*
 * Project File (.../project.graphcool)
 */
function writeProjectFile(projectInfo, resolver, path) {
    path = isValidProjectFilePath(path) ? path : constants_1.graphcoolProjectFileName;
    resolver.write(path, utils_1.projectInfoToContents(projectInfo));
}
exports.writeProjectFile = writeProjectFile;
function writeBlankProjectFileWithInfo(projectInfo, resolver, path) {
    path = isValidProjectFilePath(path) ? path : constants_1.graphcoolProjectFileName;
    const fullProjectFile = constants_1.blankProjectFileFromExampleSchema(projectInfo.alias ? projectInfo.alias : projectInfo.projectId, projectInfo.version);
    resolver.write(path, fullProjectFile);
}
exports.writeBlankProjectFileWithInfo = writeBlankProjectFileWithInfo;
function readProjectInfoFromProjectFile(resolver, path) {
    const projectId = readProjectIdFromProjectFile(resolver, path);
    if (!projectId) {
        return undefined;
    }
    const version = readVersionFromProjectFile(resolver, path);
    const schema = readDataModelFromProjectFile(resolver, path);
    return { projectId, version, schema };
}
exports.readProjectInfoFromProjectFile = readProjectInfoFromProjectFile;
function readProjectIdFromProjectFile(resolver, path) {
    const contents = resolver.read(path);
    const matches = contents.match(/# project: ([a-zA-Z0-9-]*)/);
    if (!matches || matches.length !== 2) {
        return undefined;
    }
    return matches[1];
}
exports.readProjectIdFromProjectFile = readProjectIdFromProjectFile;
function readVersionFromProjectFile(resolver, path) {
    const contents = resolver.read(path);
    const matches = contents.match(/# version: ([a-z0-9-]*)/);
    if (!matches || matches.length !== 2) {
        return undefined;
    }
    return matches[1];
}
exports.readVersionFromProjectFile = readVersionFromProjectFile;
function readDataModelFromProjectFile(resolver, path) {
    const contents = resolver.read(path);
    const dataModelStartIndex = contents.indexOf(`type`);
    const dataModel = contents.substring(dataModelStartIndex, contents.length);
    return dataModel;
}
exports.readDataModelFromProjectFile = readDataModelFromProjectFile;
function isValidProjectFilePath(projectFilePath) {
    if (!projectFilePath) {
        return false;
    }
    return projectFilePath.endsWith(constants_1.projectFileSuffix);
}
exports.isValidProjectFilePath = isValidProjectFilePath;
function isValidSchemaFilePath(schemaFilePath) {
    if (!schemaFilePath) {
        return false;
    }
    return schemaFilePath.endsWith(constants_1.schemaFileSuffix);
}
exports.isValidSchemaFilePath = isValidSchemaFilePath;
//# sourceMappingURL=file.js.map