"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cuid = require("cuid");
const bluebird = require("bluebird");
const lodash_1 = require("lodash");
function runPing(url) {
    return __awaiter(this, void 0, void 0, function* () {
        const pingUrl = () => __awaiter(this, void 0, void 0, function* () {
            const start = Date.now();
            yield fetch(url);
            return Date.now() - start;
        });
        const pings = yield bluebird.map([0, 0], pingUrl);
        return lodash_1.sum(pings) / pings.length;
    });
}
exports.regions = [
    'eu_west_1',
    'ap_northeast_1',
    'us_west_2',
];
function getFastestRegion() {
    return __awaiter(this, void 0, void 0, function* () {
        const pingResults = yield bluebird.map(exports.regions, (region) => __awaiter(this, void 0, void 0, function* () {
            const ping = yield runPing(getPingUrl(region));
            return {
                region, ping,
            };
        }));
        const fastestRegion = pingResults.reduce((min, curr) => {
            if (curr.ping < min.ping) {
                return curr;
            }
            return min;
        }, { region: '', ping: Infinity });
        return fastestRegion.region;
    });
}
exports.getFastestRegion = getFastestRegion;
exports.getDynamoUrl = (region) => `http://dynamodb.${region.replace(/_/g, '-')}.amazonaws.com`;
const getPingUrl = (region) => `${exports.getDynamoUrl(region)}/ping?x=${cuid()}`;
//# sourceMappingURL=ping.js.map