"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const test_environment_1 = require("./helpers/test_environment");
const init_1 = require("../src/commands/init");
const constants_1 = require("../src/utils/constants");
const mock_data_1 = require("./fixtures/mock_data");
require("isomorphic-fetch");
const file_1 = require("../src/utils/file");
const test_out_1 = require("./helpers/test_out");
const fetchMock = require('fetch-mock');
const debug = require('debug')('graphcool');
/*
 Tests:
- Succeeding project clone with specific name
- Succeeding project clone with specific name and different output path
- Succeeding project clone with specific name and project ID
- Succeeding project clone with specific name, project file and output path
- Failing because no project ID provided (no project file in current directory)
 */
ava_1.default.afterEach(() => {
    new test_out_1.default().write('\n');
    fetchMock.restore();
});
ava_1.default('Succeeding project clone with specific name', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedClonedProjectResponse));
    // create dummy project data
    const copyProjectId = 'abcdefghiklmn';
    const clonedProjectName = `Clone of MyProject`;
    const props = {
        name: clonedProjectName,
        copyProjectId,
    };
    // prepare environment
    const env = test_environment_1.testEnvironment({});
    const projectFilePath = constants_1.graphcoolProjectFileName;
    env.resolver.write(projectFilePath, mock_data_1.mockProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -n "Clone of MyProject" -c ${copyProjectId} `);
    yield t.notThrows(init(props, env));
    const expectedProjectFileContent = mock_data_1.clonedMockProjectFile1;
    const clonedProjectFileName = constants_1.graphcoolCloneProjectFileName(projectFilePath);
    t.is(env.resolver.read(clonedProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, clonedProjectFileName), 'nmlkjihgfedcba');
    t.is(file_1.readVersionFromProjectFile(env.resolver, clonedProjectFileName), '1');
}));
ava_1.default('Succeeding project clone with specific name and different output path', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedClonedProjectResponse));
    // create dummy project data
    const copyProjectId = 'abcdefghiklmn';
    const clonedProjectName = `Clone of MyProject`;
    const outputPath = `myclone.graphcool`;
    const props = { name: clonedProjectName, outputPath, copyProjectId };
    // prepare environment
    const env = test_environment_1.testEnvironment({});
    const projectFilePath = constants_1.graphcoolProjectFileName;
    env.resolver.write(projectFilePath, mock_data_1.mockProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -n "Clone of MyProject" -o ${outputPath} -c ${copyProjectId} `);
    yield t.notThrows(init(props, env));
    const expectedProjectFileContent = mock_data_1.clonedMockProjectFile1;
    const clonedProjectFileName = outputPath;
    t.is(env.resolver.read(clonedProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, clonedProjectFileName), 'nmlkjihgfedcba');
    t.is(file_1.readVersionFromProjectFile(env.resolver, clonedProjectFileName), '1');
}));
ava_1.default('Succeeding project clone with specific name', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedClonedProjectResponse));
    // create dummy project data
    const clonedProjectName = `Clone of MyProject`;
    const copyProjectId = `abcdefghijklmn`;
    const props = { name: clonedProjectName, copyProjectId };
    // prepare environment
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -n "Clone of MyProject" -c ${copyProjectId}`);
    yield t.notThrows(init(props, env));
    const expectedProjectFileContent = mock_data_1.clonedMockProjectFile1;
    const clonedProjectFileName = constants_1.graphcoolCloneProjectFileName(constants_1.graphcoolProjectFileName);
    t.is(env.resolver.read(clonedProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, clonedProjectFileName), 'nmlkjihgfedcba');
    t.is(file_1.readVersionFromProjectFile(env.resolver, clonedProjectFileName), '1');
}));
ava_1.default('Succeeding project clone with specific name, project file and output path', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedClonedProjectResponse));
    // create dummy project data
    const copyProjectId = `abcdefghijklmn`;
    const clonedProjectName = `Clone of MyProject`;
    const projectFile = `example.graphcool`;
    const props = { name: clonedProjectName, projectFile, copyProjectId };
    // prepare environment
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.resolver.write(projectFile, mock_data_1.mockProjectFile1);
    env.out.prefix(t._test.title, `$ graphcool init -n "Clone of MyProject" -c ${copyProjectId} -p ${projectFile}`);
    yield t.notThrows(init(props, env));
    // make sure the original project file wasn't overridden
    t.is(env.resolver.read(projectFile), mock_data_1.mockProjectFile1);
    const expectedProjectFileContent = mock_data_1.clonedMockProjectFile1;
    const clonedProjectFileName = constants_1.graphcoolCloneProjectFileName(projectFile);
    t.is(env.resolver.read(clonedProjectFileName), expectedProjectFileContent);
    t.is(file_1.readProjectIdFromProjectFile(env.resolver, clonedProjectFileName), 'nmlkjihgfedcba');
    t.is(file_1.readVersionFromProjectFile(env.resolver, clonedProjectFileName), '1');
}));
ava_1.default('Failing because no project ID provided (no project file in current directory)', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.post(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedClonedProjectResponse));
    // create dummy project data
    const clonedProjectName = `Clone of MyProject`;
    const props = { name: clonedProjectName };
    // prepare environment
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": "abcdefgh"}');
    env.out.prefix(t._test.title, `$ graphcool init -n "Clone of MyProject"`);
    yield t.throws(init(props, env));
}));
function init(props, env) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield init_1.default(props, env);
        }
        catch (e) {
            env.out.onError(e);
            throw e;
        }
    });
}
//# sourceMappingURL=clone.test.js.map