"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const test_environment_1 = require("./helpers/test_environment");
const export_1 = require("../src/commands/export");
const constants_1 = require("../src/utils/constants");
const test_out_1 = require("./helpers/test_out");
const mock_data_1 = require("./fixtures/mock_data");
const mock_data_2 = require("./fixtures/mock_data");
require("isomorphic-fetch");
const fetchMock = require('fetch-mock');
const debug = require('debug')('graphcool');
/*
 Tests:
 - Export without project file but passing project ID as argument
 - Export with project file
 - Export with multiple project files
 */
ava_1.default.afterEach(() => {
    new test_out_1.default().write('\n');
    fetchMock.restore();
});
ava_1.default('Export with project file', (t) => __awaiter(this, void 0, void 0, function* () {
    const projectFile = 'example.graphcool';
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mock_data_1.mockedExportResponse);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    // dummy export data
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(projectFile, mock_data_2.mockedPullProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = { projectFile };
    env.out.prefix(t._test.title, `$ graphcool export -p ${projectFile}`);
    yield t.notThrows(export_1.default(props, env));
}));
ava_1.default('Export with multiple project files', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    const mockedResponse = JSON.parse(mock_data_1.mockedExportResponse);
    fetchMock.post(constants_1.systemAPIEndpoint, mockedResponse);
    // dummy export data
    const env = test_environment_1.testEnvironment({});
    const projectFile1 = 'example.graphcool';
    const projectFile2 = constants_1.graphcoolProjectFileName;
    env.resolver.write(projectFile1, mock_data_2.mockedPullProjectFile1);
    env.resolver.write(projectFile2, mock_data_2.mockedPullProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = {};
    env.out.prefix(t._test.title, `$ graphcool export`);
    yield t.throws(export_1.default(props, env));
}));
//# sourceMappingURL=export.test.js.map