"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const test_environment_1 = require("./helpers/test_environment");
require("isomorphic-fetch");
const push_1 = require("../src/commands/push");
const status_1 = require("../src/commands/status");
const constants_1 = require("../src/utils/constants");
const mock_data_1 = require("./fixtures/mock_data");
const test_out_1 = require("./helpers/test_out");
const fetchMock = require('fetch-mock');
const debug = require('debug')('graphcool');
/*
Tests:
- Succeeding schema migration using --force with default project file
- Succeeding schema migration using --force without specified project file (fallback to default)
- Succeeding schema migration using --force with renamed project file
- Failing schema migration because of multiple project files
- Schema migration displaying data loss
- Status with potential data loss
*/
ava_1.default.afterEach(() => {
    new test_out_1.default().write('\n');
    fetchMock.restore();
});
ava_1.default('Succeeding schema migration using --force with default project file', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPullProjectResponse1));
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPushSchemaResponse));
    // dummy migration data
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(constants_1.graphcoolProjectFileName, mock_data_1.mockModifiedProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = { force: true, projectFilePath: constants_1.graphcoolProjectFileName };
    env.out.prefix(t._test.title, `$ graphcool push ${constants_1.graphcoolProjectFileName} --force`);
    yield t.notThrows(push(props, env));
    const expectedProjectFileContent = mock_data_1.mockProjectFile3;
    const result = env.resolver.read(`./${constants_1.graphcoolProjectFileName}`);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Succeeding schema migration using --force without specified project file (fallback to default)', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPullProjectResponse1));
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPushSchemaResponse));
    // dummy migration data
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(constants_1.graphcoolProjectFileName, mock_data_1.mockModifiedProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = { force: true };
    env.out.prefix(t._test.title, `$ graphcool push --force`);
    yield t.notThrows(push(props, env));
    const expectedProjectFileContent = mock_data_1.mockProjectFile3;
    const result = env.resolver.read(`./${constants_1.graphcoolProjectFileName}`);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Succeeding schema migration using --force with renamed project file', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPullProjectResponse1));
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPushSchemaResponse));
    // dummy migration data
    const projectFile = 'example.graphcool';
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(projectFile, mock_data_1.mockModifiedProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = { force: true };
    env.out.prefix(t._test.title, `$ graphcool push ${projectFile}`);
    yield t.notThrows(push(props, env));
    const expectedProjectFileContent = mock_data_1.mockProjectFile3;
    const result = env.resolver.read(projectFile);
    t.is(result, expectedProjectFileContent);
}));
ava_1.default('Failing schema migration because of multiple project files', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPullProjectResponse1));
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPushSchemaResponse));
    // dummy migration data
    const projectFile1 = 'example.graphcool';
    const projectFile2 = 'project.graphcool';
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(projectFile1, mock_data_1.mockProjectFile2);
    env.resolver.write(projectFile2, mock_data_1.mockProjectFile2);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = { force: true };
    env.out.prefix(t._test.title, `$ graphcool push`);
    yield t.throws(push(props, env));
    t.is(env.resolver.read(projectFile1), mock_data_1.mockProjectFile2);
    t.is(env.resolver.read(projectFile2), mock_data_1.mockProjectFile2);
}));
ava_1.default('Schema migration displaying data loss', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPullProjectResponse1));
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPushSchema1ResponseError));
    // dummy migration data
    const projectFile = 'project.graphcool';
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(projectFile, mock_data_1.mockModifiedProjectFile1);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = { force: true };
    env.out.prefix(t._test.title, `$ graphcool push`);
    yield t.notThrows(push(props, env));
    t.is(env.resolver.read(projectFile), mock_data_1.mockModifiedProjectFile1);
}));
ava_1.default('Status with potential data loss', (t) => __awaiter(this, void 0, void 0, function* () {
    // configure HTTP mocks
    fetchMock.once(constants_1.systemAPIEndpoint, JSON.parse(mock_data_1.mockedPushSchemaResponseError));
    // dummy migration data
    const projectFile = 'project.graphcool';
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(projectFile, mock_data_1.mockProjectFile2);
    env.resolver.write(constants_1.graphcoolConfigFilePath, '{"token": ""}');
    const props = {};
    env.out.prefix(t._test.title, `$ graphcool status`);
    yield t.notThrows(status_1.default(props, env));
    t.is(env.resolver.read(projectFile), mock_data_1.mockProjectFile2);
}));
function push(props, env) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield push_1.default(props, env);
        }
        catch (e) {
            env.out.onError(e);
            throw e;
        }
    });
}
//# sourceMappingURL=push.test.js.map