"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const test_resolver_1 = require("./helpers/test_resolver");
const config_1 = require("../src/utils/config");
const constants_1 = require("../src/utils/constants");
const configFileContent = '{"token":"1234"}';
/*
 Tests:
 - load noops when config file does not exist
 - load obtains configs from file
 - set overrides specified configs
 - unset removes specified config
 - get returns config value
 - save persists configs to file
 */
ava_1.default('load noops when config file does not exist', (t) => __awaiter(this, void 0, void 0, function* () {
    const resolver = new test_resolver_1.default({});
    var config = new config_1.Config(resolver);
    t.notThrows(() => { config.load(); });
}));
ava_1.default('load obtains configs from file', (t) => __awaiter(this, void 0, void 0, function* () {
    const resolver = new test_resolver_1.default({});
    resolver.write(constants_1.graphcoolConfigFilePath, configFileContent);
    var config = new config_1.Config(resolver);
    config.load();
    t.is(config.configs.token, '1234');
}));
ava_1.default('set overrides specified configs', (t) => __awaiter(this, void 0, void 0, function* () {
    const resolver = new test_resolver_1.default({});
    var config = new config_1.Config(resolver);
    config.set({ token: '1234' });
    t.is(config.configs.token, '1234');
}));
ava_1.default('unset removes specified config', (t) => __awaiter(this, void 0, void 0, function* () {
    const resolver = new test_resolver_1.default({});
    resolver.write(constants_1.graphcoolConfigFilePath, configFileContent);
    var config = new config_1.Config(resolver);
    config.unset('token');
    t.is(config.configs.token, undefined);
}));
ava_1.default('get returns config value', (t) => __awaiter(this, void 0, void 0, function* () {
    const resolver = new test_resolver_1.default({});
    resolver.write(constants_1.graphcoolConfigFilePath, configFileContent);
    var config = new config_1.Config(resolver);
    config.load();
    t.is(config.get('token'), '1234');
}));
ava_1.default('save persists configs to file', (t) => __awaiter(this, void 0, void 0, function* () {
    const resolver = new test_resolver_1.default({});
    resolver.write(constants_1.graphcoolConfigFilePath, configFileContent);
    var config = new config_1.Config(resolver);
    config.load();
    config.set({ token: '4567' });
    config.save();
    const expectedConfig = `\
{
  "token": "4567"
}\
`;
    t.is(resolver.read(constants_1.graphcoolConfigFilePath), expectedConfig);
}));
//# sourceMappingURL=utils_config.test.js.map