"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const test_out_1 = require("./helpers/test_out");
const constants_1 = require("../src/utils/constants");
const test_environment_1 = require("./helpers/test_environment");
const mock_data_1 = require("./fixtures/mock_data");
const file_1 = require("../src/utils/file");
/*
 Tests:
 - readProjectIdFromProjectFile with a file containing a project id
 - readProjectIdFromProjectFile with a file containing a project alias
 - readProjectIdFromProjectFile with a file missing a project id
 */
ava_1.default.afterEach(() => {
    new test_out_1.default().write('\n');
});
ava_1.default('readProjectIdFromProjectFile with a file containing a project id', (t) => __awaiter(this, void 0, void 0, function* () {
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(constants_1.graphcoolProjectFileName, mock_data_1.mockProjectFile1);
    const project_id = file_1.readProjectIdFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName);
    t.is(project_id, 'abcdefghijklmn');
}));
ava_1.default('readProjectIdFromProjectFile with a file containing a project alias', (t) => __awaiter(this, void 0, void 0, function* () {
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(constants_1.graphcoolProjectFileName, mock_data_1.mockProjectFileWithUppercaseAlias1);
    const project_id = file_1.readProjectIdFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName);
    t.is(project_id, 'Example');
}));
ava_1.default('readProjectIdFromProjectFile with a file missing a project id', (t) => __awaiter(this, void 0, void 0, function* () {
    const env = test_environment_1.testEnvironment({});
    env.resolver.write(constants_1.graphcoolProjectFileName, '');
    const project_id = file_1.readProjectIdFromProjectFile(env.resolver, constants_1.graphcoolProjectFileName);
    t.is(project_id, undefined);
}));
//# sourceMappingURL=utils_file.test.js.map